#
# spec file for package python-saharaclient
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-saharaclient
Version:        3.5.0
Release:        1.10
Epoch:          0
Summary:        Client library for OpenStack Sahara API
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/python-saharaclient
Source0:        https://files.pythonhosted.org/packages/source/p/python-saharaclient/python-saharaclient-3.5.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-osc-lib >= 2.0.0
BuildRequires:  python3-oslo.i18n >= 3.15.3
BuildRequires:  python3-oslo.log >= 3.36.0
BuildRequires:  python3-oslo.serialization >= 2.18.0
BuildRequires:  python3-oslo.utils >= 3.33.0
BuildRequires:  python3-oslotest
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-requests >= 2.14.2
BuildRequires:  python3-requests-mock
BuildRequires:  python3-stestr
BuildRequires:  python3-testrepository
BuildArch:      noarch

%description
Python client library for interacting with OpenStack Sahara API.

%package -n python3-saharaclient
Summary:        Client library for OpenStack Sahara API
Requires:       python3-Babel
Requires:       python3-keystoneauth1 >= 3.4.0
Requires:       python3-openstackclient >= 5.2.0
Requires:       python3-osc-lib >= 2.0.0
Requires:       python3-oslo.i18n >= 3.15.3
Requires:       python3-oslo.log >= 3.36.0
Requires:       python3-oslo.serialization >= 2.18.0
Requires:       python3-oslo.utils >= 3.33.0
Requires:       python3-requests >= 2.14.2
Requires:       python3-six >= 1.10.0

%description -n python3-saharaclient
Python client library for interacting with OpenStack Sahara API.

This package contains the Python 3.x module.

%package -n python-saharaclient-doc
Summary:        Documentation for Client library for OpenStack Sahara API
Group:          Documentation/HTML
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme

%description -n python-saharaclient-doc
Python client library for interacting with OpenStack Sahara API.

%prep
%autosetup -p1 -n python-saharaclient-3.5.0
%py_req_cleanup

%build
%{py3_build}

%install
%{py3_install}

# Build HTML docs and man page
PYTHONPATH=. PBR_VERSION=3.5.0 %sphinx_build -b html -d doc/build/doctrees doc/source doc/build/html
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%check
# we don't want to depend on hacking/flake8/pep8
rm -v saharaclient/tests/unit/test_hacking.py
python3 -m stestr.cli run

%files -n python3-saharaclient
%license LICENSE
%doc ChangeLog README.rst
%{python3_sitelib}/saharaclient
%{python3_sitelib}/*.egg-info

%files -n python-saharaclient-doc
%doc doc/build/html
%license LICENSE

%changelog
* Tue May 24 2022 cloud-devel@suse.de
- update to version 3.5.0
  - Update master for stable/xena
* Tue Oct 26 2021 cloud-devel@suse.de
- update to version 3.4.0
  - Update master for stable/wallaby
* Sun May  2 2021 cloud-devel@suse.de
- update to version 3.3.0
  - Add Python3 wallaby unit tests
  - Remove install unnecessary packages
  - Update master for stable/victoria
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 3.2.1
  - Use unittest.mock instead of third party mock
  - Update master for stable/ussuri
  - Switch to newer openstackdocstheme and reno versions
  - Ussuri contributor docs community goal
  - Remove Babel requirement
  - Bump default tox env from py37 to py38
  - Fix hacking min version to 3.0.1
  - [goal] Migrating testing to Ubuntu Focal
  - drop mock from lower-constraints
  - Remove pypy job
  - Add py38 package metadata
  - Add Python3 victoria unit tests
* Tue May 12 2020 cloud-devel@suse.de
- update to version 3.1.0
  - Update hacking for Python3
  - Switch to Ussuri jobs
  - fix: typo in tox minversion option
  - Cleanup py27 support
  - [ussuri][goal] Drop python 2.7 support and testing
  - Fix the "image register" command (OSC 5.2.0 regression)
  - Update master for stable/train
* Wed Mar 11 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 2.3.0
  - Replace git.openstack.org URLs with opendev.org URLs
  - Update sphinx from current requirements
  - py3: use the train test template and other updates
  - OpenDev Migration Patch
  - Update master for stable/stein
  - Py3: fix the OSC download job binary command
  - Add py37 and API v2 jobs (scenario, tempest)
* Wed Jul 24 2019 cloud-devel@suse.de
- update to version 2.2.1
  - OpenDev Migration Patch
  - Py3: fix the OSC download job binary command
  - Update UPPER_CONSTRAINTS_FILE for stable/stein
  - Update .gitreview for stable/stein
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 2.2.0
  - Add missing APIv2 features to client, OSC
  - Update devel info: mailing list
  - Add Python 3.6 classifier to setup.cfg
  - Update reno for stable/rocky
  - switch documentation job to new PTI
  - Preparing OSC for APIv2
  - add python 3.6 unit test job
  - import zuul job settings from project-config
  - Use templates for cover and lower-constraints
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 2.0.0
  - Clean S3 data source create/update
  - fix tox python3 overrides
  - Remove PyPI downloads
  - Fix build with Sphinx 1.7.x
  - Correct a missed job_execution->job
  - Reflect change to multiple clusters creation
  - Trivial: Update pypi url to new url
  - Allow S3 credentials in data source create
  - Revert "Fix the cover tox target (switch to stestr)"
  - Adding boot from volume
  - Reflect response fixes for jobs/jobs templates
  - Add release note link in README
  - Support of S3 data sources in OSC
  - Adding boot from volume to osc
  - Support of the improved force-delete in client
  - Switch to using stestr
  - Fix the cover tox target (switch to stestr)
  - Rework saharaclient authentication
- remove 0001-Fix-build-with-Sphinx-1.7.x.patch (upstream)
* Wed Aug  1 2018 sjamgade@suse.com
- Updated to 1.6.0
  Added patch 0001-Fix-build-with-Sphinx-1.7.x.patch
    https://review.openstack.org/#/c/564136/
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Feb 12 2018 cloud-devel@suse.de
- update to version 1.5.0 (bsc#1078607)
  - Remove -U from pip install
  - APIv2 support in client
  - Fix misleading docstring
  - Remove setting of version/release from releasenotes
  - Modify home page in setup.cfg
  - Properly document job binary "extra"
  - Auto-document members properly
  - Avoid tox_install.sh for constraints support
  - Updated from global requirements
  - Support of S3 binaries in OSC
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 1.4.0
  - Add export of node group templates to CLI
  - Update reno for stable/pike
  - Add import of node group templates
  - Reorganize the documentation following the new structure
  - Fix KeyError in "cluster scale" command
  - Adding volume_mount_prefix parameter
  - [ut] replace .testr.conf with .stestr.conf
  - Update and optimize documentation links
  - Add export of cluster templates
  - Add export of node group templates
  - Add import of Cluster Templates
  - Updated from global requirements
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 1.3.0
  - Fix a bug in jobs.py
  - Replace six.iteritems() with .items()
  - Remove log translations
  - Clone sahara hacking checks to saharaclient
  - Use 'project' instead of 'tenant'
  - Spelling replaced from "ot" to "of"
  - Set client module __version__
  - [Fix gate]Update test requirement
  - doc: migrate to openstackdocstheme
  - doc: enable warning-is-error and fix warnings
  - PYthon 3.5 is added
  - Update reno for stable/ocata
  - Fixed log messages
  - Updated from global requirements
  - Fix html_last_updated_fmt for Python3
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 1.1.0:
  - Optimize command job-binary-download
  - Add plug-in summary for osc doc
  - Update reno for stable/newton
  - Add Constraints support
  - Enable coverage report in console output
  - Fix doc build if git is absent
  - Raise exception in command "plugin configs get"
  - Add newline to strings in stdout/stderr.write()
  - Show team and repo badges on README
  - standardize release note page ordering
  - Replace logging with oslo_log.
  - Return error_code in command "job binary download"
  - [trivial] Fix spelling
  - Enable release notes translation
  - remove old cli commands
  - Updated from global requirements
  - Provide the cluster info about WebUI
* Mon Sep  5 2016 tbechtold@suse.com
  update to version 0.18.0
  * Remove discover from test-requirements
  * plugin's api update support
  * Replace tempest_lib with tempest.lib
  * Update reno for stable/mitaka
  * avoid additional requirement for building docs
  * Remove unused functional tests
  * Add openstackclient dependency back
  * Remove integration tests from saharaclient
  * Designate integration
  * Add pagination ability to Python-saharaclient
  * Migrate functional tests to openstack-client
  * Remove unused pngmath Sphinx extension
  * Use osc_lib instead of cliff
  * Add sorting ability to Python-saharaclient
  * Remove incorrectly used "# flake8: noqa"
  * include storm.pyleus in job types
  * Change plugin version 'version' parameter to 'plugin-version'
  * print statment has become a function in py3
  * Updated from global requirements
  * Use osc-lib instead of openstackclient
  * support event logs for CLI
- update _service and switch to upstream spec template
* Mon May 16 2016 jengelh@inai.de
- Bump python requirement to 2.7 per 0.13's changelog notice
  that py26 is dropped.
* Mon Mar 14 2016 dmueller@suse.com
- update to 0.13.0:
  * Add debug testenv in tox
  * Added volume_mount_prefix for node group templates
  * Adding ability to get plugin processes via CLI
  * Adding ability to provide name or ID of the flavor in CLI
  * Adding ability to unset fields with update calls
  * Adding autogenerated saharaclient API docs
  * Adding Clusters support to CLI
  * Adding Cluster Templates support to CLI
  * Adding get_resource_id method to CLI utils
  * Adding "health verification --show" CLI call
  * Adding Images support to CLI
  * Adding indications of results after delete operations
  * Adding Job Binaries support to CLI
  * Adding Jobs support to CLI
  * Adding Job Templates support to CLI
  * Adding Job Types support to CLI
  * Adding missed public/protected support for jobs creation
  * Adding Node Group Templates support to CLI
  * Adding release notes for saharaclient
  * Adding return of updated image for update_image, update_tags
  * Adding Sahara CLI overview to docs and fixing warnings
  * Adding sahara_url and endpoint_type to OpenstackClient CLI
  * Adding sphinx extension for CLI docs autogeneration
  * Adding update and minor fixes to Data Sources CLI
  * Add *.log to gitignore
  * Add releasenotes to sahara client
  * Add the mising requriements
  * Allowing for shares to be edited on an existing cluster
  * Change ignore-errors to ignore_errors
  * Changing public/protected options handling
  * Delete python bytecode before every test run
  * Deprecated tox -downloadcache option removed
  * Deprecation of the Sahara CLI
  * Drop py33 support
  * Enabling DeprecationWarning if session is not provided
  * Fix bypass-url for CLI
  * Fixed problem with tags update
  * Fix functional tests in gate
  * Fix functional tests in saharaclient
  * Fixing cluster and node group template updates
  * Fixing cluster creation with neutron network via CLI
  * Fixing cluster scaling via CLI
  * Fixing data source update in CLI
  * Fixing updates for CLI
  * Fixing updates via CLI
  * Images CLI improvement
  * Improve readme contents
  * Keystoneclient to keystoneauth migration
  * Last sync from oslo-incubator
  * Making desc parameter of update_image optional
  * Making parameters of job binaries create optional
  * Making parameters of job create optional
  * Making parameters of job executions create optional
  * print usage when no argument is specified for python3
  * Remove argparse dependency from requirements.txt file
  * Remove `data source update` from setup.cfg
  * Remove duplicate .coverage in .gitignore file
  * remove netaddr from requirements
  * Remove py26 support
  * Replace deprecated library function os.popen() with subprocess
  * Replacing hard coded cluster status using utils in sahara-client
  * Shows reason of failure in base.get
  * Updated from global requirements
  * Update .gitreview for stable/liberty
  * Updating saharaclient api docs
  * Use ostestr instead of the custom pretty_tox.sh
  * verifications impl for saharaclient
* Sun Oct  4 2015 tbechtold@suse.com
- update to 0.11.1:
  * Updating saharaclient api docs
  * Updated from global requirements
  * Change ignore-errors to ignore_errors
  * Fixing cluster and node group template updates
  * Remove `data source update` from setup.cfg
  * Adding missed public/protected support for jobs creation
  * Fix functional tests in saharaclient
  * Update .gitreview for stable/liberty
- adjust Requires according to requirements.txt
* Wed Sep 16 2015 tbechtold@suse.com
- update to 0.11.0:
  * Updated from global requirements
  * Support updates and ACL for objects
  * Updated from global requirements
  * Updated from global requirements
  * Improve help strings
  * Fixing query string for multiple opts
  * Updated from global requirements
  * Adding Data Sources support to CLI
  * Fix backward compat issue for job interfaces
  * Add initial commit for integration with Openstackclient
  * Updated from global requirements
  * API to mount manila shares to clusters
  * Add support OS_ENDPOINT_TYPE env variable to CLI
  * Add support of use_autoconfig field
  * Add to_dict() method to Resource class
  * Updated from global requirements
  * Add cluster-scale command to the CLI
  * Adding interface argument for job template and job
  * Fix _get_by_id_or_name method
  * Updated from global requirements
  * Updated from global requirements
  * Allow multiple clusters creation
  * Sorting 'job-list' output by start_time
  * Including 'start_time' column at 'sahara job-list' command
  * Updated from global requirements
  * pass environment variables of proxy to tox
  * Updated from global requirements
  * Updated from global requirements
  * Adding job binary editing to library and CLI
  * Pass OpenStack environment variables to client tests
  * Adding data source editing to library and CLI
  * Updated from global requirements
  * Adding node group template editing to CLI
  * Adding cluster template editing to CLI
  * Updated from global requirements
  * Drop use of 'oslo' namespace package
  * Updated from global requirements
  * Try getting old service type if session used
  * Add .coveragerc to saharaclient
  * Update README to work with release tools
  * Uncap library requirements for liberty
  * Add regions support to saharaclient
  * Provide user-agent in saharaclient
  * Mark saharaclient as being a universal wheel
  * Add CONTRIBUTING.rst
  * Port to Python 3
  * add --name option to assign name to job-binary-internal
  * Rework authentication
  * Add support for job-types-list
  * Add post_test_hook for functional tests
  * Copy functional tests from tempest CLI
  * Updated from global requirements
  * Add support for show_events parameter
  * Added support of instance locality
- Adjust Requires according to requirements.txt
* Fri Apr 24 2015 tbechtold@suse.com
- Use %%{version} in source
* Thu Apr 23 2015 tbechtold@suse.com
- Switch to version 0.8.0
* Wed Apr 22 2015 tbechtold@suse.com
- Switch to master
* Tue Apr  7 2015 tbechtold@suse.com
- update to 0.8.0:
  * Removed cluster validation on client side
  * Add how to participate doc
  * Added --bypass-url support for keystone 3
  * Updated from global requirements
  * Remove strutils from openstack/common
  * Remove importutils from openstack-common.conf
  * Pass service type argument in Sahara CLI
  * Fixed work with 'data_processing' service spelling
  * Added support of is_proxy_gateway field for node group
  * Pass endpoint_type to Sahara client constructor
  * Use pretty-tox for better test output
  * Update apiclient.exceptions oslo-incubator module
  * Update apiclient.auth oslo-incubator module
  * Update _i18n oslo-incubator module
  * Remove unused uuidutils dep
  * Remove obsolete gettextutils
  * Remove unused apiclient oslo files
  * apiclient.auth is required since d02f0e1d (21 sep 2014)
  * Add find_unique base manager method
  * Add ability to get events from saharaclient
  * Using oslo_* instead of oslo.*
  * Updated from global requirements
  * Added SSL-related parameters to the client
  * Added ability to pass image_id for node group
  * Fix output of supported api versions
  * Use requests-mock for mocking
  * Remove cyclic dependency
  * Fix for sahara CLI
  * Enable W292 and E123
  * Move to hacking 0.10
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Workflow documentation is now in infra-manual
  * Update oslo-incubator importutils
  * Update oslo-incubator apiclient.exceptions
  * Update oslo-incubator cliutils
  * Updating oslo-incubator
  * Update oslo-incubator strutils
  * Set default service_type to "data-processing" in client
  * Added unit tests for python bindings
- Add python_requires to services
- Adjust Requires according to requirements.txt and test-requirements.txt
* Tue Dec  9 2014 dmueller@suse.com
- update to 0.7.6:
  * Replacing data_processing with data-processing
  * Adding support for query filtering to list() calls
  * Fixed old style class declaration
  * Add Support for Keystone V3 CLI
* Mon Nov  3 2014 dmueller@suse.com
- update to 0.7.5:
  * Add volume_type support to node group templates
  * Support Cinder availability zones
  * Support Nova availability zones
  * Fix arguments order in assertEqual
  * Use base utils from oslo-incubator instead copy-pasted from nova
  * Updated from global requirements
* Mon Sep 22 2014 dmueller@suse.com
- update to 0.7.3:
  * Fixed backward compatibility of sahara client
  * Sync oslo cliutils module
  * Sync oslo apiclient.exceptions module
  * Updated from global requirements
  * Sync oslo strutils module
  * [client] Fixed pep8 and py27 tasks on tox 1.7.2
  * Add warn re sorting requirements
  * Add doc8 tox env
  * Work toward Python 3.4 support and testing
  * Fix duplicate help strings
* Thu Sep 11 2014 dmueller@suse.com
- update to 0.7.1:
  * Updated from global requirements
  * Added hadling of non-json response from Sahara
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * updating link to Sahara docs
  * Add oslo.i18n lib to requirements
  * Update oslo-incubator cliutils module
  * Update oslo-incubator apiclient module
  * Update oslo-incubator strutils module
  * Update oslo-incubator gettextutils module
  * Update oslo-incubator apiclient.exceptions module
  * Remove docutils pin
  * Jar files for pig and mapreduce EDP tests
  * Update code for new hacking/pep8/flake8 global requirements
  * Make Cluster Template accept default_image_id field
  * Fixes ambiguous cli output between "None" and NoneType
  * Updated from global requirements
  * Remove vim editor configuration from comments
  * Updated from global requirements
  * Updated from global requirements
  * Don't set json content type for non-json data
  * Updated from global requirements
  * Added new hacking version to requirements
  * Updated from global requirements
  * Remove excutils from openstack-common.conf
  * Updated from global requirements
  * Fix network passing for cluster-template-create
  * removed unused methods from nova.utils
  * Update oslo-incubator cliutils
  * Update oslo-incubator apiclient.exceptions
  * Update oslo-incubator importutils
  * Update oslo-incubator strutils (and gettextutils)
  * Remove timeutils from openstack-common.conf
  * Updated from global requirements
  * use strutils.to_slug() instead of utils.slugify()
  * replace string format arguments with function parameters
  * Add help string to job-create
  * Updated from global requirements
  * Add EDP jobs to cli integration tests
  * Add cli cluster creation and teardown test
  * Updated from global requirements
  * Updated from global requirements
  * Stub integration tests for vanilla, vanilla2 and hdp plugins
  * Restructure tests directory in preparation for cli integration tests
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
* Tue Apr  1 2014 dmueller@suse.com
- Update to version python-saharaclient-0.7.0.1.g507cfe8:
  * Updated from global requirements
  0.7.0
  * Remove savanna aliases
  * Add README file
  0.6.0
* Wed Mar 19 2014 dmueller@suse.com
- rename to python-saharaclient
* Mon Mar 10 2014 cloud-devel@suse.de
- Update to version python-savannaclient-0.5.0.5.gbb9a581:
  * Add excutils and timeutils to openstack/common
  * Update oslo-incubator apiclient.exceptions modules
* Tue Mar  4 2014 cloud-devel@suse.de
- Update to version python-savannaclient-0.5.0.2.g882e37a:
  * Add missed PrettyTable requirement
* Sat Mar  1 2014 cloud-devel@suse.de
- Update to version python-savannaclient-0.5.0.1.g69a13cb:
  * Updated from global requirements
  0.5.0
* Wed Feb 26 2014 cloud-devel@suse.de
- Update to version python-savannaclient-0.4.1.93.gc391001:
  * Args should be passed as a list on job creation
  * Check for presence of 'credentials' before filtering
  * Check for presence of 'extra' before filtering
* Tue Feb 25 2014 cloud-devel@suse.de
- Update to version python-savannaclient-0.4.1.88.g53fdf51:
  * Updated from global requirements
* Mon Feb 24 2014 cloud-devel@suse.de
- Update to version python-savannaclient-0.4.1.87.g8ac7a3b:
  * Improve help strings
  * Update oslo-incubator cliutils module
* Sat Feb 22 2014 cloud-devel@suse.de
- Update to version python-savannaclient-0.4.1.83.g93fa4d8:
  * Api Exception improvement
  * Update oslo-incubator apiclient.exceptions module
  * update oslo-incubator strutils module
  * Update oslo-incubator gettextutils module
  * Update oslo-incubator importutils module
  * Add importutils module
* Fri Feb 21 2014 cloud-devel@suse.de
- Update to version python-savannaclient-0.4.1.75.gf0b7777:
  * Fix typo in doc string
  * Move client docs to the client
  * Add savannaclient/version.py to store version info
  * Make the single entrypoint for client
* Tue Feb 18 2014 cloud-devel@suse.de
- Update to version python-savannaclient-0.4.1.70.g15cb7e9:
  * Remove dependent module py3kcompat
* Thu Feb 13 2014 cloud-devel@suse.de
- Update to version python-savannaclient-0.4.1.69.g202e311:
  * Removed copy_if_defined function from ClusterManager
* Tue Feb 11 2014 speilicke@suse.com
- Update to version python-savannaclient-0.4.1.67.g89ab87a:
  * print_list(): do not call decode() on a text string
  * Some improvements in tox.ini
  * Sync with global requirements
  * Changed base Resource class to prevent changing of passed arguments
  * Add --name option to image unregister & tag cmds
  * Remove job_exec_data argument
  * Add --name option to appropriate delete commands
  * Add --name option to appropriate show commands
  * Add space to name for consistency
  * Map neutron_management_network to net_id in CLI
  * Add job-create to CLI
  * Add job-template-create to CLI
  * Fixed issue when savanna url is not provided
- Replace git_tarballs source service with download_files and set_version
  + Use upstream URL as source (enables verification)
* Sat Feb  1 2014 opensuse-cloud@opensuse.org
- Update to version 0.4.1.48:
  + Update oslo-incubator strutils module
  + Update oslo-incubator cliutils module
* Thu Jan 30 2014 opensuse-cloud@opensuse.org
- Update to version 0.4.1.46:
  + Refactor display of a job
  + Make --bypass-url default to env(BYPASS_URL)
* Wed Jan 29 2014 opensuse-cloud@opensuse.org
- Update to version 0.4.1.44:
  + Updated from global requirements
  + Refactor display of a job binary
  + Add job-binary-create to CLI
  + Refactor display of job template
* Mon Jan 27 2014 opensuse-cloud@opensuse.org
- Update to version 0.4.1.36:
  + Send credentials only when they are provided
* Sat Jan 25 2014 opensuse-cloud@opensuse.org
- Update to version 0.4.1.35:
  + Refactor display of a single data-source
  + Add data-source-create to CLI
* Fri Jan 24 2014 opensuse-cloud@opensuse.org
- Update to version 0.4.1.33:
  + Add cluster-template-create to CLI
  + Add cluster-create to CLI
  + Fix default service-type name in help
  + Add data-source-list to CLI
  + Add data-source-show to CLI
  + Add data-source-delete to CLI
  + Add job-binary-data-list to CLI
  + Add job-binary-data-delete to CLI
  + Add job-binary-list to CLI
  + Add job-binary-show to CLI
  + Add job-binary-delete to CLI
  + Add job-template-list to CLI
  + Add job-template-show to CLI
  + Add job-template-delete to CLI
  + Add job-list to CLI
  + Add job-show to CLI
  + Add job-delete to CLI
  + Refactor display of job-binary-data elements
  + Add job-binary-data-create to CLI
* Wed Jan 22 2014 opensuse-cloud@opensuse.org
- Update to version 0.4.1.14:
  + Remove version from setup.cfg
  + Add node-group-template-create to CLI
* Tue Jan 21 2014 opensuse-cloud@opensuse.org
- Update to version 0.4.0.dev11:
  + Make plugin commands singular
  + Add node-group-template-show command to CLI
  + Add cluster-template-show command to CLI
  + Refactor display of node group template
  + Refactor display of cluster template
  + Refactor display of cluster
  + Add --json option to node-group-template-show
  + Add --json option to cluster-template-show
  + Add --json option to cluster-show
* Thu Jan 16 2014 dmueller@suse.com
- remove pep8/flake8 requires, come from hacking now
* Thu Jan 16 2014 opensuse-cloud@opensuse.org
- Update to version 0.4.0.dev2:
  + Force wrap line for cluster-show
* Wed Jan 15 2014 opensuse-cloud@opensuse.org
- Update to version 0.4.0.dev37:
  + Add some pretty printing for list fields
  + Allow passing extra args to JobExecutionsManager.create()
  + Add pretty printing of node group fields
  + Clean up printing of image details
  + Clean up versions display in plugins-show
  + JobExecutionsManager.create() should handle input_id/output_id == None
* Tue Jan 14 2014 opensuse-cloud@opensuse.org
- Update to version 0.4.0.dev27:
  + Add initial cluster-* commands to CLI
  + Add initial node-group-template-* commands to CLI
  + Add initial cluster-template-* commands to CLI
* Fri Jan 10 2014 opensuse-cloud@opensuse.org
- Update to version 0.4.0.dev24:
  + Python 3: use six.iteritems() instead of iteritems()
  + Python3: use six.moves.urllib.parse instead of urlparse
  + Add run_test.sh for running tests
  + Update oslo-incubator gettextutils module
  + Add initial image-* commands to CLI
  + Update oslo-incubator py3kcompat module
  + Update oslo-incubator apiclient module
* Fri Jan  3 2014 opensuse-cloud@opensuse.org
- Update to version 0.4.0.dev11:
  + Adding the ability to modify cluster templates
  + Adding the ability to modify node group templates
  + Add initial Savanna CLI
  + Add basic tests for savanna CLI
* Wed Dec 18 2013 dmueller@suse.com
- Initial package
